// SPDX-FileCopyrightText: 2022 Tobias Leupold <tl at stonemx dot de>
//
// SPDX-License-Identifier: GPL-3.0-or-later

// Local includes

#include "MarkersSettingsPage.h"

#include "SharedObjects/Settings.h"

#include "shared/Markers.h"
#include "shared/MarkersDisplay.h"

// Qt includes
#include <QDebug>
#include <QVBoxLayout>
#include <QLabel>
#include <QGroupBox>

MarkersSettingsPage::MarkersSettingsPage(Settings *settings, QWidget *parent)
    : AbstractSettingsPage(tr("Markierungen"), parent)
{
    auto *label = new QLabel(tr("Die hier verwendete Vorlage kann via „Extras“ → „Einstellungen“ → "
                                "„Vorlage Markierungen“ aus einer Datenbank erzeugt werden!"));
    label->setWordWrap(true);
    layout()->addWidget(label);

    const auto markersTemplate = settings->markersTemplate();
    const auto specialMarkers = settings->specialMarkers();
    const auto singlesManagement = settings->singlesManagementTemplate();

    auto *markersDisplay = new MarkersDisplay(&markersTemplate, &specialMarkers, &singlesManagement);
    layout()->addWidget(markersDisplay);
    markersDisplay->refresh();

    layout()->addStretch();
}

void MarkersSettingsPage::saveSettings()
{
    // The markers data is set by the NewTournamentDialog itself, as it can't be changed here
}
