// SPDX-FileCopyrightText: 2019-2022 Tobias Leupold <tl at stonemx dot de>
//
// SPDX-License-Identifier: GPL-3.0-or-later

#ifndef TOURNAMENTSETTINGS_H
#define TOURNAMENTSETTINGS_H

// Local includes
#include "shared/Tournament.h"
#include "shared/Markers.h"
#include "shared/RegistrationColumns.h"
#include "shared/Draw.h"
#include "shared/OptionalPages.h"

// Qt includes
#include <QObject>
#include <QJsonValue>

class TournamentSettings : public QObject
{
    Q_OBJECT

public:
    explicit TournamentSettings(QObject *parent);
    int version() const;
    void setLoadingDb(bool state);
    bool loadingDb() const;
    bool load(const QString &data);
    void setDbTournamentSettingsVersion(int version);
    int dbTournamentSettingsVersion() const;
    QString toString() const;
    QString updateSettingsFromDbV8(const QString &data) const;

    // Value access functions

    void setTournamentMode(Tournament::Mode tournamentMode);
    Tournament::Mode tournamentMode() const;
    bool isPairMode() const;
    bool isSinglePlayerMode() const;

    void setScoreType(Tournament::ScoreType type);
    Tournament::ScoreType scoreType() const;

    void setBoogerScore(int score);
    const int &boogerScore() const;

    void setBoogersPerRound(int count);
    int boogersPerRound() const;

    void setDrawSettings(const Draw::Settings &settings);
    const Draw::Settings &drawSettings() const;

    void setRegistrationColumns(const QVector<RegistrationColumns::Column> &data);
    const QVector<RegistrationColumns::Column> &registrationColumns() const;

    void setRegistrationListHeaderHidden(bool state);
    bool registrationListHeaderHidden() const;

    void setAutoSelectPairs(bool state);
    bool autoSelectPairs() const;

    void setSelectByLastRound(bool state);
    bool selectByLastRound() const;

    void setNoTableNumbers(bool state);
    bool noTableNumbers() const;

    void setIncludeOpponentGoals(bool state);
    bool includeOpponentGoals() const;

    void setGrayOutUnimportantGoals(bool state);
    bool grayOutUnimportantGoals() const;

    const QVector<OptionalPages::Page> &optionalPages() const;
    void setOptionalPageShown(OptionalPages::Page page, bool state);

    void setMuckturnierVersion(const QString &muckturnierVersion);
    const QString &muckturnierVersion() const;

    void setTournamentOpen(bool state);
    bool tournamentOpen() const;
    void initializeTournamentOpen();
    bool tournamentOpenChanged() const;

    void setMarker(Markers::Type type, int id);
    void setMarkers(const QHash<Markers::Type, int> &markers);
    int marker(Markers::Type type) const;
    QHash<Markers::Type, int> specialMarkers() const;

    void setSinglesManagement(const Markers::SinglesManagement &data);
    const Markers::SinglesManagement &singlesManagement() const;

private: // Functions
    void reset();
    QVariant getValue(const QJsonObject &json, const QString &key, QJsonValue::Type type) const;

private: // Variables

    // Values represented in the tournament template
    Tournament::Mode m_tournamentMode;
    Tournament::ScoreType m_scoreType;
    int m_boogerScore;
    int m_boogersPerRound;
    Draw::Settings m_drawSettings;
    QVector<RegistrationColumns::Column> m_registrationColumns;
    bool m_registrationListHeaderHidden;
    bool m_autoSelectPairs;
    bool m_selectByLastRound;
    bool m_noTableNumbers;
    bool m_includeOpponentGoals;
    bool m_grayOutUnimportantGoals;
    QVector<OptionalPages::Page> m_optionalPages;

    // Database-read values with fallback values
    QString m_muckturnierVersion;
    bool m_tournamentOpen;
    bool m_originalTournamentOpen;
    QHash<Markers::Type, int> m_marker;
    Markers::SinglesManagement m_singlesManagement;

    // Other variables needed by the class itself
    bool m_loadingDb = false;
    int m_dbTournamentSettingsVersion = -1;
    QHash<QString, QJsonValue> m_unhandledValues;

};

#endif // TOURNAMENTSETTINGS_H
