// SPDX-FileCopyrightText: 2022 Tobias Leupold <tl at stonemx dot de>
//
// SPDX-License-Identifier: GPL-3.0-or-later

// Local includes
#include "ScoreHelper.h"
#include "ServerProtocol.h"

// Qt includes
#include <QJsonObject>
#include <QJsonArray>

namespace sp = ServerProtocol;

namespace ScoreHelper
{

QJsonObject scoreToJson(const Scores::Score &score)
{
    QJsonArray tables;
    for (const auto table : score.tables) {
        tables.append(table);
    }

    QJsonArray pairs;
    for (const auto &pair : score.pairs) {
        pairs.append(pair);
    }

    QJsonArray scores;
    for (const auto &pairResults : score.scores) {
        QJsonArray singleScore;
        for (const auto singleResult : pairResults) {
            singleScore.append(singleResult);
        }
        scores.append(singleScore);
    }

    return QJsonObject { { sp::action,      sp::scoreRequest },
                         { sp::tablesList,  tables },
                         { sp::playersList, pairs },
                         { sp::scoresList,  scores } };
}

Scores::Score JsonToScore(const QJsonObject &json)
{
    Scores::Score score;

    const auto jsonTables = json.value(sp::tablesList).toArray();
    for (const auto &table : jsonTables) {
        score.tables.append(table.toInt());
    }

    const auto jsonPairs = json.value(sp::playersList).toArray();
    for (const auto &pair : jsonPairs) {
        score.pairs.append(pair.toString());
    }

    const auto jsonScores = json.value(sp::scoresList).toArray();
    for (const auto &jsonPairResult : jsonScores) {
        const auto jsonPairResultArray = jsonPairResult.toArray();
        QVector<int> pairResult;
        for (const auto &result : jsonPairResultArray) {
            pairResult.append(result.toInt());
        }
        score.scores.append(pairResult);
    }

    return score;
}

}
