// SPDX-FileCopyrightText: 2020 Tobias Leupold <tl at stonemx dot de>
//
// SPDX-License-Identifier: GPL-3.0-or-later

// Local includes
#include "MinimumViewportScroll.h"
#include "MinimumViewportWidget.h"

// Qt includes
#include <QResizeEvent>
#include <QDebug>
#include <QScrollBar>

MinimumViewportScroll::MinimumViewportScroll(Qt::Orientation orientation, QWidget *parent)
    : QScrollArea(parent),
      m_orientation(orientation)
{
}

void MinimumViewportScroll::resizeEvent(QResizeEvent *event)
{
    QScrollArea::resizeEvent(event);

    if (widget() == nullptr) {
        return;
    }

    switch (m_orientation) {
    case Qt::Horizontal:
        setMinimumWidth(qobject_cast<MinimumViewportWidget *>(widget())->minimumViewport().width()
                        + (verticalScrollBar()->isVisible() ? verticalScrollBar()->width()
                                                            : 0));
        break;
    case Qt::Vertical:
        setMinimumHeight(qobject_cast<MinimumViewportWidget *>(widget())->minimumViewport().height()
                        + (horizontalScrollBar()->isVisible() ? horizontalScrollBar()->height()
                                                              : 0));
        break;
    }
}
